var searchData=
[
  ['benchmark_5fop',['BENCHMARK_OP',['../dense__blas_8cpp.html#a0c464e202ab39eece213320f33750b8b',1,'dense_blas.cpp']]],
  ['benchmark_5fruns',['BENCHMARK_RUNS',['../direct__solve_8cpp.html#adb0225facf93cb5236fe7a5c0bf50f18',1,'BENCHMARK_RUNS():&#160;direct_solve.cpp'],['../benchmarks_2scheduler_8cpp.html#adb0225facf93cb5236fe7a5c0bf50f18',1,'BENCHMARK_RUNS():&#160;scheduler.cpp'],['../solver_8cpp.html#adb0225facf93cb5236fe7a5c0bf50f18',1,'BENCHMARK_RUNS():&#160;solver.cpp'],['../examples_2benchmarks_2sparse_8cpp.html#adb0225facf93cb5236fe7a5c0bf50f18',1,'BENCHMARK_RUNS():&#160;sparse.cpp']]],
  ['benchmark_5fvector_5fsize',['BENCHMARK_VECTOR_SIZE',['../opencl_8cpp.html#a5200eec7d1a17198a5f76785a1f53417',1,'BENCHMARK_VECTOR_SIZE():&#160;opencl.cpp'],['../benchmarks_2scheduler_8cpp.html#a5200eec7d1a17198a5f76785a1f53417',1,'BENCHMARK_VECTOR_SIZE():&#160;scheduler.cpp']]],
  ['blas3_5fmatrix_5fsize',['BLAS3_MATRIX_SIZE',['../blas3range_8cpp.html#a182e37b13d9e73b3fa8226df1fce81cd',1,'blas3range.cpp']]],
  ['boost_5fublas_5fndebug',['BOOST_UBLAS_NDEBUG',['../matrix__product__float__double_8hpp.html#aa2c0476a142c9e172a2c18d054b6c210',1,'BOOST_UBLAS_NDEBUG():&#160;matrix_product_float_double.hpp'],['../solver_8cpp.html#aa2c0476a142c9e172a2c18d054b6c210',1,'BOOST_UBLAS_NDEBUG():&#160;solver.cpp']]]
];
